/*
    Copyright (C) 2010  Kevin Funk <krf@electrostorm.net>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

*/

#include "networkingsession.h"

#include "networkingcontrol_p.h"

#ifdef Q_OS_WINCE
#include "networkingcontrolmanager_wince.h"
#else
#warning "Implement me on this platform"
#endif

#include "soliddefs_p.h"

#include <QtCore/QDebug>

using namespace Solid;

SOLID_GLOBAL_STATIC(NetworkingControlPrivate, globalNetworkingControlManager)

NetworkingControlPrivate::NetworkingControlPrivate()
    : m_manager(new NetworkingControlManager)
{
    qDebug() << Q_FUNC_INFO;
}

NetworkingControlPrivate::~NetworkingControlPrivate()
{
    qDebug() << Q_FUNC_INFO;

    delete m_manager;

    qDeleteAll(m_networkingSessions);
}

void NetworkingControlPrivate::registerSession(NetworkingSession* session)
{
    qDebug() << "Registering session in Controller:" << session;
    
    if (m_networkingSessions.contains(session))
        return;

    m_networkingSessions.append(session);

    // connect so that we are getting notified when the session object is deleted
    connect(session, SIGNAL(destroyed(QObject*)), SLOT(sessionDestroyed(QObject*)));
    connect(session, SIGNAL(stateChanged(Solid::NetworkingSession::State)), SLOT(updateManager()));

}

void NetworkingControlPrivate::sessionDestroyed(QObject* object)
{
    qDebug() << Q_FUNC_INFO << object;

    // note: cannot use qobject_cast here, always returns 0
    NetworkingSession* session = reinterpret_cast<NetworkingSession*>(object);
    if (!session)
        return;

    qDebug() << "Session destroyed, removing from list:" << session;

    m_networkingSessions.removeOne(session);
    updateManager();
}

QList<Solid::NetworkingSession*> NetworkingControlPrivate::activeNetworkingSessions() const
{
    const NetworkingSession::State activeState = NetworkingSession::Established;

    QList<Solid::NetworkingSession*> list;
    foreach(NetworkingSession* session, m_networkingSessions) {
        if (session->state() == activeState) {
            list.append(session);
            qDebug() << "Active networking session:" << session << "from:" << session->parent();
        }
    }
    return list;
}

void NetworkingControlPrivate::updateManager()
{
    qDebug() << Q_FUNC_INFO;

    int count = activeNetworkingSessions().size();
    if (count > 0)
        m_manager->establishConnection();
    else
        m_manager->releaseConnection();

    qDebug() << "Active networking sessions count:" << count;
}

void NetworkingControl::Controller::registerSession(NetworkingSession* session)
{
    globalNetworkingControlManager->registerSession(session);
}

/* Controller part */
Solid::NetworkingControl::Controller::Controller()
{
}

NetworkingControl::Controller* NetworkingControl::controller()
{
    return globalNetworkingControlManager;
}

#include "networkingcontrol.moc"
#include "networkingcontrol_p.moc"
