/*
    Copyright (C) 2010  Kevin Funk <krf@electrostorm.net>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

*/

#include "networkingcontrolmanager_wince.h"

#include "soliddefs_p.h"

// Windows includes, do NOT change order!
#include <objbase.h>
#include <initguid.h>
#include <connmgr.h>
#include <shellapi.h>
#include <winbase.h>

#include <QtCore/QDebug>

using namespace Solid;

NetworkingControlManager::NetworkingControlManager()
    : m_handle(NULL)
{
}

NetworkingControlManager::~NetworkingControlManager()
{
}

void NetworkingControlManager::establishConnection()
{
    // check if there's a connection available
    if (m_handle != NULL) {
        qDebug() << "Establish: Already connected, not requesting new connection";
        return;
    }

    // Make sure Connection Manager is ready
    HANDLE hConnMgr = NULL;
    BOOL bAvailable = FALSE;
        hConnMgr = ConnMgrApiReadyEvent();

    if(!hConnMgr) {
        qDebug("!hConnMgr");
        return;
    }

    // Wait for 1 second to see if Connection Manager has signaled the event
    DWORD dwResult = WaitForSingleObject(hConnMgr, 1000);

    if(dwResult == WAIT_OBJECT_0)
        bAvailable = TRUE;

    // Close the event handle
    if(hConnMgr)
        CloseHandle(hConnMgr);

    // Did it connect ok?
    if (!bAvailable) {
        qDebug("!bAvailable");
        return;
    }

    // fill connection info
    CONNMGR_CONNECTIONINFO connInfo;
    ZeroMemory(&connInfo, sizeof(CONNMGR_CONNECTIONINFO));
    connInfo.cbSize = sizeof(CONNMGR_CONNECTIONINFO);
    connInfo.dwPriority = CONNMGR_PRIORITY_USERINTERACTIVE;
    connInfo.dwParams = CONNMGR_PARAM_GUIDDESTNET;
    //connInfo.dwFlags = CONNMGR_FLAG_PROXY_HTTP;
    connInfo.bExclusive = FALSE;
    connInfo.bDisabled = FALSE;
    connInfo.guidDestNet = IID_DestNetInternet;

    HRESULT hr = ConnMgrEstablishConnection(&connInfo, &m_handle);
    if (hr != S_OK) {
        qDebug() << "Manager: Establishing failed, hr:" << hr;
    }
    else {
        qDebug() << "Manager: Establishing okay, hConn:" << m_handle;
    }

    // update state
    m_state = NetworkingSession::Established;
}

void NetworkingControlManager::releaseConnection()
{
    if (m_handle == NULL) {
        qDebug() << "Release: Not connected, doing nothing";
        return;
    }
    
    HRESULT hr = ConnMgrReleaseConnection(m_handle, 3);
    if (hr != S_OK) {
        qDebug() << "Manager: Release failed, hr:" << hr;
    }
    else {
        qDebug() << "Manager: Release okay, hConn:" << m_handle;
    }
    CloseHandle(m_handle);
    m_handle = NULL;

    // update state
    m_state = NetworkingSession::Released;
}
