/*
    Copyright (C) 2010  Kevin Funk <krf@electrostorm.net>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

*/

#include "networkingsession.h"

#include <QtCore/QDebug>
#include "networkingcontrol.h"

using namespace Solid;

namespace Solid {

class NetworkingSessionPrivate
{
public:
    NetworkingSessionPrivate(NetworkingSession* session);
    ~NetworkingSessionPrivate();

    NetworkingSession::State m_state;

private:
    void init();

    NetworkingSession* q;
};

}

NetworkingSessionPrivate::NetworkingSessionPrivate(NetworkingSession* session)
    : q(session)
    , m_state(NetworkingSession::Invalid)
{
    qDebug() << Q_FUNC_INFO;

    init();
}

NetworkingSessionPrivate::~NetworkingSessionPrivate()
{
    qDebug() << Q_FUNC_INFO;
}

void NetworkingSessionPrivate::init()
{
    qDebug() << Q_FUNC_INFO;
}

Solid::NetworkingSession::NetworkingSession(QObject* parent)
    : QObject(parent)
    , d_ptr(new NetworkingSessionPrivate(this))
{
    NetworkingControl::controller()->registerSession(this);
}

Solid::NetworkingSession::~NetworkingSession()
{
    delete d_ptr;
}

void Solid::NetworkingSession::establishConnection()
{
    Q_D(NetworkingSession);
    if (d->m_state == Established)
        return;

    d->m_state = NetworkingSession::Established;
    emit stateChanged(d->m_state);
}

void Solid::NetworkingSession::releaseConnection()
{
    Q_D(NetworkingSession);
    if (d->m_state == Released)
        return;

    d->m_state = NetworkingSession::Released;
    emit stateChanged(d->m_state);
}

NetworkingSession::State Solid::NetworkingSession::state() const
{
    Q_D(const NetworkingSession);
    return d->m_state;
}

#include "networkingsession.moc"
