/*
    Copyright (C) 2010  Kevin Funk <krf@electrostorm.net>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

*/

#ifndef SOLID_NETWORKINGSESSION_H
#define SOLID_NETWORKINGSESSION_H

#include <solid/solid_export.h>

#include <QtCore/QObject>

namespace Solid
{

class NetworkingSessionPrivate;

class SOLID_EXPORT NetworkingSession
    : public QObject
{
    Q_OBJECT
    Q_DECLARE_PRIVATE(NetworkingSession);

public:
    enum State {
        Invalid = 0,
        Established,
        Released
    };

    explicit NetworkingSession(QObject* parent = 0);
    virtual ~NetworkingSession();

    /**
     * Establish and hold connection until releaseConnection() is called.
     * @see releaseConnection()
     */
    SOLID_EXPORT void establishConnection();

    /**
     * Release connection again
     */
    SOLID_EXPORT void releaseConnection();

    /**
     * Current state of this session
     */
    State state() const;

Q_SIGNALS:
    void stateChanged(Solid::NetworkingSession::State state);
    void connectionEstablished();
    void connectionReleased();

private:
    NetworkingSessionPrivate* d_ptr;
};

}

#endif // NETWORKINGSESSION_H
